@@ -1,6 +1,6 @@
 BEGIN { $| = 1; print "1..5\n"; }
 END {print "not ok 1\n" unless $loaded;}
-use List::Member 0.03;
+use List::Member 0.04;
 our $loaded=1;
 print "ok 1\n";
 
@@ -16,5 +16,5 @@ print "ok 3\n";
 print "not " unless member('tikkumolam',@look_in) eq nota_member();
 print "ok 4\n";
 
-print "not " unless isa_member('foo',@look_in);
+print "not " unless defined member('foo',@look_in);
 print "ok 5\n";
